==> kdevplatform-1.6.0_5.txz: usr/local/lib/cmake/kdevplatform/KDevPlatformTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDevPlatformImport__sublime" for configuration "Release"
set_property(TARGET KDevPlatformImport__sublime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__sublime PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kparts"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libsublime.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libsublime.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__sublime )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__sublime "/usr/local/lib/libsublime.so.7.0.0" )

# Import target "KDevPlatformImport__kdevplatforminterfaces" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatforminterfaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatforminterfaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kcmutils;KDE4__knotifyconfig;KDE4__threadweaver;KDE4__krosscore"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kparts;KDE4__ktexteditor"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatforminterfaces.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatforminterfaces.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatforminterfaces )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatforminterfaces "/usr/local/lib/libkdevplatforminterfaces.so.7.0.0" )

# Import target "KDevPlatformImport__kdevplatformproject" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformproject APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformproject PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformutil;KDevPlatformImport__kdevplatformlanguage;KDE4__kio"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformproject.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformproject.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformproject )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformproject "/usr/local/lib/libkdevplatformproject.so.7.0.0" )

# Import target "KDevPlatformImport__kdevplatformlanguage" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformlanguage APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformlanguage PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kparts;KDE4__ktexteditor;KDE4__threadweaver;KDE4__knewstuff3;KDevPlatformImport__kdevplatformutil;grantlee_core"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformlanguage.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformlanguage.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformlanguage )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformlanguage "/usr/local/lib/libkdevplatformlanguage.so.7.0.0" )

# Import target "KDevPlatformImport__kdevplatformshell" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformshell APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformshell PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kfile;KDE4__kcmutils;KDE4__kparts;KDE4__knotifyconfig;KDE4__ktexteditor;KDE4__threadweaver;KDE4__krosscore;KDevPlatformImport__kdevplatforminterfaces;KDevPlatformImport__kdevplatformproject;KDevPlatformImport__kdevplatformvcs;KDevPlatformImport__kdevplatformlanguage;KDevPlatformImport__kdevplatformutil;KDevPlatformImport__kdevplatformdocumentation"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformoutputview;KDevPlatformImport__sublime;KDevPlatformImport__kdevplatformdebugger"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformshell.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformshell.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformshell )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformshell "/usr/local/lib/libkdevplatformshell.so.7.0.0" )

# Import target "KDevPlatformImport__kdevplatformutil" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformutil APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformutil PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kcmutils;KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformutil.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformutil.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformutil )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformutil "/usr/local/lib/libkdevplatformutil.so.7.0.0" )

# Import target "KDevPlatformImport__kdevplatformoutputview" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformoutputview APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformoutputview PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces;KDevPlatformImport__kdevplatformutil"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformoutputview.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformoutputview.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformoutputview )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformoutputview "/usr/local/lib/libkdevplatformoutputview.so.7.0.0" )

# Import target "KDevPlatformImport__kdevplatformvcs" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformvcs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformvcs PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kparts;KDevPlatformImport__kdevplatformutil;KDevPlatformImport__kdevplatformproject;KDevPlatformImport__kdevplatformlanguage"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformoutputview;KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformvcs.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformvcs.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformvcs )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformvcs "/usr/local/lib/libkdevplatformvcs.so.7.0.0" )

# Import target "KDevPlatformImport__kdevplatformdebugger" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformdebugger APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformdebugger PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__ktexteditor"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces;KDevPlatformImport__kdevplatformutil"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformdebugger.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformdebugger.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformdebugger )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformdebugger "/usr/local/lib/libkdevplatformdebugger.so.7.0.0" )

# Import target "KDevPlatformImport__kdevplatformdocumentation" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformdocumentation APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformdocumentation PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformdocumentation.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformdocumentation.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformdocumentation )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformdocumentation "/usr/local/lib/libkdevplatformdocumentation.so.7.0.0" )

# Import target "KDevPlatformImport__kdevplatformtests" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformtests APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformtests PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformshell;KDevPlatformImport__kdevplatformlanguage;KDevPlatformImport__kdevplatformproject"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformtests.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformtests.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformtests )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformtests "/usr/local/lib/libkdevplatformtests.so.7.0.0" )

# Import target "KDevPlatformImport__kdevplatformjsontests" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformjsontests APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformjsontests PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "qjson;KDevPlatformImport__kdevplatformlanguage"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformjsontests.so.7.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformjsontests.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformjsontests )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformjsontests "/usr/local/lib/libkdevplatformjsontests.so.7.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kdevplatform-1.7.3.txz: usr/local/lib/cmake/kdevplatform/KDevPlatformTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDevPlatformImport__sublime" for configuration "Release"
set_property(TARGET KDevPlatformImport__sublime APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__sublime PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kparts"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libsublime.so.8.0.0"
  IMPORTED_SONAME_RELEASE "libsublime.so.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__sublime )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__sublime "/usr/local/lib/libsublime.so.8.0.0" )

# Import target "KDevPlatformImport__kdevplatforminterfaces" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatforminterfaces APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatforminterfaces PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__knotifyconfig;KDE4__kio;KDE4__kcmutils;KDE4__threadweaver"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kparts;KDE4__ktexteditor"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatforminterfaces.so.8.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatforminterfaces.so.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatforminterfaces )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatforminterfaces "/usr/local/lib/libkdevplatforminterfaces.so.8.0.0" )

# Import target "KDevPlatformImport__kdevplatformproject" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformproject APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformproject PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformutil;KDevPlatformImport__kdevplatformlanguage;KDE4__kio"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformproject.so.8.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformproject.so.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformproject )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformproject "/usr/local/lib/libkdevplatformproject.so.8.0.0" )

# Import target "KDevPlatformImport__kdevplatformlanguage" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformlanguage APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformlanguage PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kparts;KDE4__ktexteditor;KDE4__threadweaver;KDE4__knewstuff3;KDevPlatformImport__kdevplatformutil;grantlee_core"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformlanguage.so.8.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformlanguage.so.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformlanguage )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformlanguage "/usr/local/lib/libkdevplatformlanguage.so.8.0.0" )

# Import target "KDevPlatformImport__kdevplatformshell" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformshell APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformshell PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kfile;KDE4__kcmutils;KDE4__kparts;KDE4__knotifyconfig;KDE4__ktexteditor;KDE4__threadweaver;KDevPlatformImport__kdevplatforminterfaces;KDevPlatformImport__kdevplatformproject;KDevPlatformImport__kdevplatformvcs;KDevPlatformImport__kdevplatformlanguage;KDevPlatformImport__kdevplatformutil;KDevPlatformImport__kdevplatformdocumentation"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__sublime;KDevPlatformImport__kdevplatformoutputview;KDevPlatformImport__kdevplatformdebugger"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformshell.so.8.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformshell.so.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformshell )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformshell "/usr/local/lib/libkdevplatformshell.so.8.0.0" )

# Import target "KDevPlatformImport__kdevplatformutil" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformutil APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformutil PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kcmutils;KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformutil.so.8.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformutil.so.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformutil )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformutil "/usr/local/lib/libkdevplatformutil.so.8.0.0" )

# Import target "KDevPlatformImport__kdevplatformoutputview" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformoutputview APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformoutputview PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces;KDevPlatformImport__kdevplatformutil"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformoutputview.so.8.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformoutputview.so.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformoutputview )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformoutputview "/usr/local/lib/libkdevplatformoutputview.so.8.0.0" )

# Import target "KDevPlatformImport__kdevplatformvcs" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformvcs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformvcs PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio;KDE4__kparts;KDevPlatformImport__kdevplatformutil;KDevPlatformImport__kdevplatformproject;KDevPlatformImport__kdevplatformlanguage"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformoutputview;KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformvcs.so.8.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformvcs.so.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformvcs )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformvcs "/usr/local/lib/libkdevplatformvcs.so.8.0.0" )

# Import target "KDevPlatformImport__kdevplatformdebugger" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformdebugger APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformdebugger PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__ktexteditor"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces;KDevPlatformImport__kdevplatformutil"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformdebugger.so.8.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformdebugger.so.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformdebugger )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformdebugger "/usr/local/lib/libkdevplatformdebugger.so.8.0.0" )

# Import target "KDevPlatformImport__kdevplatformdocumentation" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformdocumentation APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformdocumentation PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatforminterfaces"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformdocumentation.so.8.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformdocumentation.so.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformdocumentation )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformdocumentation "/usr/local/lib/libkdevplatformdocumentation.so.8.0.0" )

# Import target "KDevPlatformImport__kdevplatformtests" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformtests APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformtests PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDevPlatformImport__kdevplatformshell;KDevPlatformImport__kdevplatformlanguage;KDevPlatformImport__kdevplatformproject"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformtests.so.8.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformtests.so.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformtests )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformtests "/usr/local/lib/libkdevplatformtests.so.8.0.0" )

# Import target "KDevPlatformImport__kdevplatformjsontests" for configuration "Release"
set_property(TARGET KDevPlatformImport__kdevplatformjsontests APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDevPlatformImport__kdevplatformjsontests PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "qjson"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "Qt4::QtCore;-pthread;KDevPlatformImport__kdevplatformlanguage"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdevplatformjsontests.so.8.0.0"
  IMPORTED_SONAME_RELEASE "libkdevplatformjsontests.so.8"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDevPlatformImport__kdevplatformjsontests )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDevPlatformImport__kdevplatformjsontests "/usr/local/lib/libkdevplatformjsontests.so.8.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
